==> aime_0.59.orig.tar.gz: aime-0.59.orig/include/newfuncts.h <==
#ifndef _NEWFUNCTS_H
#define _NEWFUNCTS_H

#include <stdio.h>
#include "mudtypes.h"
#include "lexer.h"

class Flags;
class Action;
class Text;
class Level;
class Quest;
class Marker;
class Location;
class Door;
class Moveable;
class Wearable;
class Rope;
class Weapon;
class Merger;
class Key;
class Boat;
class Book;
class Mobile;
class Money;
class Food;
class Specials;
class Spell;
class Skill;
class Shop;
class Pager;
class Strings;
class Connection;
class Area_Dbase;
class Editor;
class Strings;
class Code;
class Player;
class Letter;
class Mailer;
class Input;

class Parse;
class Level_Chain;
class LinkedNode;
class Mud;
class ErrLog;
class SysLog;
class Data_Log;
class User_Dbase;
class Port;
class Access_List;
class Verb_List;
class Object_List;
class Level_List;
class Builder;
class Verb;
class Entity;
class Race;
class Bulletin;
class BullEntry;
class Configs;
class Mask;
class Inclination;
class Talent;
class ChatLine;

struct reload_obj_info;
struct Com_List;
struct b_node_l;
struct b_node_a;
struct params;
struct Edit_Line;
struct flag_long_int;
struct worn_item;
struct handler_struct;
struct special_holder;
struct chain_link;
struct token_data;
struct lex_holder;
struct mem_unit;
struct fighting_ind;
struct rank_list;
struct level_list;
struct quest_list;
struct vars;
struct status_type;
struct verb_data;
struct shop_item;
struct buy_request;
struct brief_stack;
struct prompt_stack;
struct snoop_struct;

Flags    *new_Flags(int the_num);
void     delete_Flags(Flags *the_flag);
Action   *new_Action(char *the_name);
void     delete_Action(Action *the_action);
ChatLine *new_ChatLine(char *the_name);
void     delete_ChatLine(ChatLine *the_chatline);
Text     *new_Text(char *the_name, int text_type);
void     delete_Text(Text *the_text);
//Level    *new_Level(char *the_name);
//void     delete_Level(Level *the_level);
Quest    *new_Quest(char *the_name);
void     delete_Quest(Quest *the_quest);
Marker   *new_Marker(char *the_name, char *the_area);
void     delete_Marker(Marker *the_marker);
Location *new_Location(char *the_name, char *the_area);
void     delete_Location(Location *the_loc);
Door     *new_Door(char *the_name, char *the_area);
void     delete_Door(Door *the_door);
Moveable *new_Moveable(char *the_name, char *the_area);
void     delete_Moveable(Moveable *the_moveable);
Wearable *new_Wearable(char *the_name, char *the_area);
void     delete_Wearable(Wearable *the_wearable);
Rope     *new_Rope(char *the_name, char *the_area);
void     delete_Rope(Rope *the_rope);
Weapon   *new_Weapon(char *the_name, char *the_area);
void     delete_Weapon(Weapon *the_weapon);
Merger   *new_Merger(char *the_name, char *the_area);
void     delete_Merger(Merger *the_merger);
Key      *new_Key(char *the_name, char *the_area);
void     delete_Key(Key *the_key);
Boat     *new_Boat(char *the_name, char *the_area);
void     delete_Boat(Boat *the_boat);
Book     *new_Book(char *the_name, char *the_area);
void     delete_Book(Book *the_book);
Mobile   *new_Mobile(char *the_name, char *the_area);
void     delete_Mobile(Mobile *the_mobile);
Money    *new_Money(char *the_name, char *the_area);
void     delete_Money(Money *the_money);
Food     *new_Food(char *the_name, char *the_area);
void     delete_Food(Food *the_food);
Specials *new_Specials(char *the_name, char *the_area);
void     delete_Specials(Specials *the_specials);
Spell    *new_Spell(char *the_name);
void     delete_Spell(Spell *the_spell);
Skill    *new_Skill(char *the_name);
void     delete_Skill(Skill *the_skill);
reload_obj_info *new_reload_obj_info();
void     delete_reload_obj_info(reload_obj_info *the_obj);
Com_List *new_Com_List();
void     delete_Com_List(Com_List *the_obj);
Shop     *new_Shop();
void     delete_Shop(Shop *the_obj);
Pager    *new_Pager(char *filename, int num_lines);
Pager    *new_Pager(Strings *the_str, int num_lines);
void     delete_Pager(Pager *the_pager);
b_node_a *new_b_node_a();
void     delete_b_node_a(b_node_a *the_obj);
b_node_l *new_b_node_l();
void     delete_b_node_l(b_node_l *the_obj);
//char     *new_char(int num_char);
//void     delete_char(char *the_char);
#ifdef WIN32
Connection *new_Connection();
#else
Connection *new_Connection(int sock_num, MudObject *sock_own);
#endif
void     delete_Connection(Connection *the_conn);
// Editor   *new_Editor(char *the_str);
// Editor   *new_Editor();
// Editor   *new_Editor(FILE *the_file);
// void     delete_Editor(Editor *the_obj);
Area_Dbase *new_Area_Dbase(char *areaname);
void     delete_Area_Dbase(Area_Dbase *the_obj);
params   *new_params();
void     delete_params(params *the_obj);
long     *new_long();
void     delete_long(long *the_obj);
int      *new_int();
void     delete_int(int *the_obj);
Strings  *new_Strings(char *the_str);
Strings  *new_Strings();
void     delete_Strings(Strings *the_obj);
Code     *new_Code(char *the_str);
Code     *new_Code(Spec_Func the_funct);
void     delete_Code(Code *the_obj);
Player   *new_Player(char *the_str);
Player   *new_Player();
void     delete_Player(Player *the_obj);
Letter   *new_Letter();
void     delete_Letter(Letter *the_obj);
Mailer   *new_Mailer(char *the_username, load_type the_mode);
void     delete_Mailer(Mailer *the_obj);
BullEntry *new_BullEntry(Bulletin *assign_board);
void      delete_BullEntry(BullEntry *the_obj);
Bulletin *new_Bulletin(char *the_name, int build_port);
void     delete_Bulletin(Bulletin *the_obj);
Edit_Line *new_Edit_Line();
void     delete_Edit_Line(Edit_Line *the_obj);
//flag_long_int *new_flag_long_int();
//void     delete_flag_long_int(flag_long_int *the_obj);
worn_item *new_worn_item();
void     delete_worn_item(worn_item *the_obj);
handler_struct *new_handler_struct();
void     delete_handler_struct(handler_struct *the_obj);
special_holder *new_special_holder();
void     delete_special_holder(special_holder *the_obj);
chain_link *new_chain_link();
void     delete_chain_link(chain_link *the_obj);
token_data *new_token_data();
void     delete_token_data(token_data *the_obj);
lex_holder *new_lex_holder();
void     delete_lex_holder(lex_holder *the_obj);
mem_unit *new_mem_unit();
void     delete_mem_unit(mem_unit *the_obj);
fighting_ind *new_fighting_ind();
void     delete_fighting_ind(fighting_ind *the_obj);
rank_list *new_rank_list();
void     delete_rank_list(rank_list *the_obj);
Edit_Line *new_Edit_Line();
void     delete_Edit_Line(Edit_Line *the_obj);
level_list *new_level_list();
void     delete_level_list(level_list *the_obj);
quest_list *new_quest_list();
void     delete_quest_list(quest_list *the_obj);
vars     *new_vars();
void     delete_vars(vars *the_obj);
status_type *new_status_type();
void     delete_status_type(status_type *the_obj);
Input    *new_Input();
void     delete_Input(Input *the_obj);
Parse    *new_Parse(char *the_input, Entity *the_verb);
void     delete_Parse(Parse *the_obj);
Level_Chain *new_Level_Chain(char *the_chain);
void     delete_Level_Chain(Level_Chain *the_obj);
LinkedNode *new_LinkedNode(MudObject *the_node);
void     delete_LinkedNode(LinkedNode *the_obj);
Mud      *new_Mud(bool quiet_mode);
void     delete_Mud(Mud *the_obj);
ErrLog   *new_ErrLog();
void     delete_ErrLog(ErrLog *the_obj);
SysLog   *new_SysLog();
void     delete_SysLog(SysLog *the_obj);
Data_Log *new_Data_Log(char *log_name, char *file_name);
void     delete_Data_Log(Data_Log *the_obj);
User_Dbase *new_User_Dbase();
void     delete_User_Dbase(User_Dbase *the_obj);
Configs  *new_Configs();
void     delete_Configs(Configs *the_obj);
Port     *new_Port(int the_port, bool quiet_mode);
void     delete_Port(Port *the_obj);
Access_List *new_Access_List(char *filename);
void     delete_Access_List(Access_List *the_obj);
Verb_List *new_Verb_List(verb_data the_data[]);
void     delete_Verb_List(Verb_List *the_obj);
Object_List *new_Object_List(ErrLog *the_log, bool quiet_mode);
void     delete_Object_List(Object_List *the_obj);
Level_List *new_Level_List(ErrLog *the_log, Object_List *obj_dbase);
void     delete_Level_List(Level_List *the_obj);
Builder  *new_Builder(Connection *the_conn);
Builder  *new_Builder(void);
void     delete_Builder(Builder *the_obj);
Verb     *new_Verb(char *the_name);
void     delete_Verb(Verb *the_obj);
Race     *new_Race(char *the_name);
void     delete_Race(Race *the_obj);
Inclination *new_Inclination(char *the_name);
void     delete_Inclination(Inclination *the_obj);
Talent   *new_Talent(char *the_name);
void     delete_Talent(Talent *the_obj);
Mask     *new_Mask(char *the_name);
void     delete_Mask(Mask *the_obj);
shop_item *new_shop_item();
void     delete_shop_item(shop_item *the_obj);
buy_request *new_buy_request();
void     delete_buy_request(buy_request *the_obj);
token_record *new_token_record();
void     delete_token_record(token_record *the_obj);
string_record *new_string_record();
void     delete_string_record(string_record *the_obj);
brief_stack *new_brief_stack();
void     delete_brief_stack(brief_stack *the_obj);
prompt_stack *new_prompt_stack();
void     delete_prompt_stack(prompt_stack *the_obj);
snoop_struct *new_snoop_struct();
void     delete_snoop_struct(snoop_struct *the_obj);

#endif

==> aime_0.60.3.orig.tar.gz: aime-0.60.3.orig/include/newfuncts.h <==
#ifndef _NEWFUNCTS_H
#define _NEWFUNCTS_H

#include <stdio.h>
#include "mudtypes.h"
#include "lexer.h"

class Flags;
class Action;
class Text;
class Level;
class Quest;
class Marker;
class Location;
class Door;
class Moveable;
class Wearable;
class Rope;
class Weapon;
class Merger;
class Key;
class Boat;
class Book;
class Mobile;
class Money;
class Food;
class Specials;
class Spell;
class Skill;
class Shop;
class Pager;
class Strings;
class Connection;
class Area_Dbase;
class Editor;
class Strings;
class Code;
class Player;
class Letter;
class Mailer;
class Input;

class Parse;
class Level_Chain;
//class LinkedNode;
class Mud;
class ErrLog;
class SysLog;
class Data_Log;
class User_Dbase;
class Port;
class Access_List;
class Verb_List;
class Object_List;
class Level_List;
class Builder;
class Verb;
class Entity;
class Race;
class Bulletin;
class BullEntry;
class Configs;
class Mask;
class Inclination;
class Talent;
class ChatLine;

struct reload_obj_info;
struct Com_List;
//struct b_node_l;
//struct b_node_a;
//struct params;
struct Edit_Line;
struct flag_long_int;
struct worn_item;
struct handler_struct;
struct special_holder;
struct chain_link;
struct token_data;
struct lex_holder;
struct mem_unit;
struct fighting_ind;
struct rank_list;
struct level_list;
struct quest_list;
struct vars;
struct status_type;
struct verb_data;
struct shop_item;
struct buy_request;
struct brief_stack;
struct prompt_stack;
struct snoop_struct;

//Flags    *new_Flags(int the_num);
//void     delete_Flags(Flags *the_flag);
Action   *new_Action(char *the_name);
void     delete_Action(Action *the_action);
ChatLine *new_ChatLine(char *the_name);
void     delete_ChatLine(ChatLine *the_chatline);
Text     *new_Text(char *the_name, int text_type);
void     delete_Text(Text *the_text);
//Level    *new_Level(char *the_name);
//void     delete_Level(Level *the_level);
Quest    *new_Quest(char *the_name);
void     delete_Quest(Quest *the_quest);
Marker   *new_Marker(char *the_name, char *the_area);
void     delete_Marker(Marker *the_marker);
Location *new_Location(char *the_name, char *the_area);
void     delete_Location(Location *the_loc);
Door     *new_Door(char *the_name, char *the_area);
void     delete_Door(Door *the_door);
Moveable *new_Moveable(char *the_name, char *the_area);
void     delete_Moveable(Moveable *the_moveable);
//Wearable *new_Wearable(char *the_name, char *the_area);
//void     delete_Wearable(Wearable *the_wearable);
Rope     *new_Rope(char *the_name, char *the_area);
void     delete_Rope(Rope *the_rope);
Weapon   *new_Weapon(char *the_name, char *the_area);
void     delete_Weapon(Weapon *the_weapon);
Merger   *new_Merger(char *the_name, char *the_area);
void     delete_Merger(Merger *the_merger);
Key      *new_Key(char *the_name, char *the_area);
void     delete_Key(Key *the_key);
Boat     *new_Boat(char *the_name, char *the_area);
void     delete_Boat(Boat *the_boat);
Book     *new_Book(char *the_name, char *the_area);
void     delete_Book(Book *the_book);
Mobile   *new_Mobile(char *the_name, char *the_area);
void     delete_Mobile(Mobile *the_mobile);
Money    *new_Money(char *the_name, char *the_area);
void     delete_Money(Money *the_money);
Food     *new_Food(char *the_name, char *the_area);
void     delete_Food(Food *the_food);
Specials *new_Specials(char *the_name, char *the_area);
void     delete_Specials(Specials *the_specials);
Spell    *new_Spell(char *the_name);
void     delete_Spell(Spell *the_spell);
Skill    *new_Skill(char *the_name);
void     delete_Skill(Skill *the_skill);
reload_obj_info *new_reload_obj_info();
void     delete_reload_obj_info(reload_obj_info *the_obj);
Com_List *new_Com_List();
void     delete_Com_List(Com_List *the_obj);
Shop     *new_Shop();
void     delete_Shop(Shop *the_obj);
Pager    *new_Pager(char *filename, int num_lines);
Pager    *new_Pager(Strings *the_str, int num_lines);
void     delete_Pager(Pager *the_pager);
//b_node_a *new_b_node_a();
//void     delete_b_node_a(b_node_a *the_obj);
//b_node_l *new_b_node_l();
//void     delete_b_node_l(b_node_l *the_obj);
//char     *new_char(int num_char);
//void     delete_char(char *the_char);
#ifdef WIN32
Connection *new_Connection();
#else
Connection *new_Connection(int sock_num, MudObject *sock_own);
#endif
void     delete_Connection(Connection *the_conn);
// Editor   *new_Editor(char *the_str);
// Editor   *new_Editor();
// Editor   *new_Editor(FILE *the_file);
// void     delete_Editor(Editor *the_obj);
//Area_Dbase *new_Area_Dbase(char *areaname);
//void     delete_Area_Dbase(Area_Dbase *the_obj);
//params   *new_params();
//void     delete_params(params *the_obj);
long     *new_long();
void     delete_long(long *the_obj);
int      *new_int();
void     delete_int(int *the_obj);
// Strings  *new_Strings(char *the_str);
// Strings  *new_Strings();
// void     delete_Strings(Strings *the_obj);
Code     *new_Code(char *the_str);
Code     *new_Code(Spec_Func the_funct);
void     delete_Code(Code *the_obj);
Player   *new_Player(char *the_str);
Player   *new_Player();
void     delete_Player(Player *the_obj);
Letter   *new_Letter();
void     delete_Letter(Letter *the_obj);
Mailer   *new_Mailer(char *the_username, load_type the_mode);
void     delete_Mailer(Mailer *the_obj);
BullEntry *new_BullEntry(Bulletin *assign_board);
void      delete_BullEntry(BullEntry *the_obj);
Bulletin *new_Bulletin(char *the_name, int build_port);
void     delete_Bulletin(Bulletin *the_obj);
Edit_Line *new_Edit_Line();
void     delete_Edit_Line(Edit_Line *the_obj);
//flag_long_int *new_flag_long_int();
//void     delete_flag_long_int(flag_long_int *the_obj);
//worn_item *new_worn_item();
//void     delete_worn_item(worn_item *the_obj);
handler_struct *new_handler_struct();
void     delete_handler_struct(handler_struct *the_obj);
special_holder *new_special_holder();
void     delete_special_holder(special_holder *the_obj);
chain_link *new_chain_link();
void     delete_chain_link(chain_link *the_obj);
token_data *new_token_data();
void     delete_token_data(token_data *the_obj);
lex_holder *new_lex_holder();
void     delete_lex_holder(lex_holder *the_obj);
mem_unit *new_mem_unit();
void     delete_mem_unit(mem_unit *the_obj);
fighting_ind *new_fighting_ind();
void     delete_fighting_ind(fighting_ind *the_obj);
rank_list *new_rank_list();
void     delete_rank_list(rank_list *the_obj);
Edit_Line *new_Edit_Line();
void     delete_Edit_Line(Edit_Line *the_obj);
level_list *new_level_list();
void     delete_level_list(level_list *the_obj);
quest_list *new_quest_list();
void     delete_quest_list(quest_list *the_obj);
vars     *new_vars();
void     delete_vars(vars *the_obj);
status_type *new_status_type();
void     delete_status_type(status_type *the_obj);
Input    *new_Input();
void     delete_Input(Input *the_obj);
Parse    *new_Parse(char *the_input, Entity *the_verb);
void     delete_Parse(Parse *the_obj);
Level_Chain *new_Level_Chain(char *the_chain);
void     delete_Level_Chain(Level_Chain *the_obj);
//LinkedNode *new_LinkedNode(MudObject *the_node);
//void     delete_LinkedNode(LinkedNode *the_obj);
Mud      *new_Mud(bool quiet_mode);
void     delete_Mud(Mud *the_obj);
ErrLog   *new_ErrLog();
void     delete_ErrLog(ErrLog *the_obj);
SysLog   *new_SysLog();
void     delete_SysLog(SysLog *the_obj);
Data_Log *new_Data_Log(char *log_name, char *file_name);
void     delete_Data_Log(Data_Log *the_obj);
User_Dbase *new_User_Dbase();
void     delete_User_Dbase(User_Dbase *the_obj);
Configs  *new_Configs();
void     delete_Configs(Configs *the_obj);
Port     *new_Port(int the_port, bool quiet_mode);
void     delete_Port(Port *the_obj);
Access_List *new_Access_List(char *filename);
void     delete_Access_List(Access_List *the_obj);
Verb_List *new_Verb_List(verb_data the_data[]);
void     delete_Verb_List(Verb_List *the_obj);
Object_List *new_Object_List(ErrLog *the_log, bool quiet_mode);
void     delete_Object_List(Object_List *the_obj);
Level_List *new_Level_List(ErrLog *the_log, Object_List *obj_dbase);
void     delete_Level_List(Level_List *the_obj);
Builder  *new_Builder(Connection *the_conn);
Builder  *new_Builder(void);
void     delete_Builder(Builder *the_obj);
Verb     *new_Verb(char *the_name);
void     delete_Verb(Verb *the_obj);
Race     *new_Race(char *the_name);
void     delete_Race(Race *the_obj);
Inclination *new_Inclination(char *the_name);
void     delete_Inclination(Inclination *the_obj);
Talent   *new_Talent(char *the_name);
void     delete_Talent(Talent *the_obj);
Mask     *new_Mask(char *the_name);
void     delete_Mask(Mask *the_obj);
shop_item *new_shop_item();
void     delete_shop_item(shop_item *the_obj);
buy_request *new_buy_request();
void     delete_buy_request(buy_request *the_obj);
token_record *new_token_record();
void     delete_token_record(token_record *the_obj);
string_record *new_string_record();
void     delete_string_record(string_record *the_obj);
brief_stack *new_brief_stack();
void     delete_brief_stack(brief_stack *the_obj);
prompt_stack *new_prompt_stack();
void     delete_prompt_stack(prompt_stack *the_obj);
snoop_struct *new_snoop_struct();
void     delete_snoop_struct(snoop_struct *the_obj);

#endif
